**ARTKIT** is a Python framework developed by `BCG X <https://www.bcg.com/x>`_ for automating prompt-based
testing and evaluation of Gen AI applications.

.. Begin-Badges

|pypi| |conda| |python_versions| |code_style| |made_with_sphinx_doc| |License_badge|

.. End-Badges

License
---------------------------

*ARTKIT* is licensed under Apache 2.0 as described in the
`LICENSE <https://github.com/BCG-X-Official/artkit/main/LICENSE>`_ file.

.. |conda| image:: https://anaconda.org/bcgx/artkit/badges/version.svg
    :target: https://anaconda.org/bcgx/artkit

.. |pypi| image:: https://badge.fury.io/py/artkit.svg
    :target: https://pypi.org/project/artkit/

.. |python_versions| image:: https://img.shields.io/badge/python-3.10%7C3.12-blue.svg
    :target: https://www.python.org/downloads/

.. |code_style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. |made_with_sphinx_doc| image:: https://img.shields.io/badge/Made%20with-Sphinx-1f425f.svg
    :target: https://bcg-x-official.github.io/pytools/index.html

.. |license_badge| image:: https://img.shields.io/badge/License-Apache%202.0-olivegreen.svg
    :target: https://opensource.org/licenses/Apache-2.0
    